
import { DollarSign } from 'lucide-react';
import { Input } from "@/components/ui/input";
import { Label } from "@/components/ui/label";

interface FinancialInfoProps {
  formData: any;
  setFormData: (data: any) => void;
}

export const FinancialInfoSection = ({ formData, setFormData }: FinancialInfoProps) => {
  const handleChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const { name, value } = e.target;
    setFormData(prev => ({ ...prev, [name]: value }));
  };

  return (
    <div className="glass-panel p-6 animate-fade-up" style={{ animationDelay: '0.1s' }}>
      <div className="flex items-center gap-2 mb-6">
        <div className="w-8 h-8 rounded-full bg-brand-blue/10 flex items-center justify-center">
          <DollarSign className="w-4 h-4 text-brand-blue" />
        </div>
        <h3 className="font-semibold text-lg">Financial Information</h3>
      </div>

      <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
        <div className="space-y-2">
          <Label htmlFor="monthlyIncome">Monthly Income (BDT)</Label>
          <Input 
            id="monthlyIncome" 
            name="monthlyIncome" 
            type="number" 
            placeholder="50000" 
            className="input-field"
            value={formData.monthlyIncome || ''}
            onChange={handleChange}
          />
        </div>

        <div className="space-y-2">
          <Label htmlFor="monthlySpending">Monthly Spending (BDT)</Label>
          <Input 
            id="monthlySpending" 
            name="monthlySpending" 
            type="number" 
            placeholder="30000" 
            className="input-field"
            value={formData.monthlySpending || ''}
            onChange={handleChange}
          />
        </div>

        <div className="space-y-2">
          <Label htmlFor="existingLoanAmount">Existing Loan Amount (BDT)</Label>
          <Input 
            id="existingLoanAmount" 
            name="existingLoanAmount" 
            type="number" 
            placeholder="100000" 
            className="input-field"
            value={formData.existingLoanAmount || ''}
            onChange={handleChange}
          />
        </div>

        <div className="space-y-2">
          <Label htmlFor="activeLoans">Number of Active Loans</Label>
          <Input 
            id="activeLoans" 
            name="activeLoans" 
            type="number" 
            placeholder="1" 
            className="input-field"
            value={formData.activeLoans || ''}
            onChange={handleChange}
          />
        </div>

        <div className="space-y-2">
          <Label htmlFor="familyMembers">Number of Family Members</Label>
          <Input 
            id="familyMembers" 
            name="familyMembers" 
            type="number" 
            placeholder="3" 
            className="input-field"
            value={formData.familyMembers || ''}
            onChange={handleChange}
          />
        </div>

        <div className="space-y-2">
          <Label htmlFor="creditInquiries">Credit Inquiries (Last 6 Months)</Label>
          <Input 
            id="creditInquiries" 
            name="creditInquiries" 
            type="number" 
            placeholder="2" 
            className="input-field"
            value={formData.creditInquiries || ''}
            onChange={handleChange}
          />
        </div>
      </div>
    </div>
  );
};
